@@ -31,13 +31,13 @@ class SentenceTransformer(nn.Sequential):
             logging.info("Load pretrained SentenceTransformer: {}".format(model_name_or_path))
             model_path = model_name_or_path
 
-            if not os.path.isdir(model_path):
+            if not os.path.isdir(model_path) and not model_path.startswith('http://') and not model_path.startswith('https://'):
                 logging.info("Did not find folder {}. Assume to download model from server.".format(model_path))
                 model_path = __DOWNLOAD_SERVER__ + model_path + '.zip'
 
             if model_path.startswith('http://') or model_path.startswith('https://'):
                 model_url = model_path
-                folder_name = model_url.replace("https://", "").replace("http://", "").replace("/", "_")[:250]
+                folder_name = model_url.replace("https://", "").replace("http://", "").replace("/", "_")[:250].rstrip('.zip')
 
                 try:
                     from torch.hub import _get_torch_home
@@ -59,6 +59,7 @@ class SentenceTransformer(nn.Sequential):
                         http_get(model_url, zip_save_path)
                         with ZipFile(zip_save_path, 'r') as zip:
                             zip.extractall(model_path)
+                        os.remove(zip_save_path)
                     except requests.exceptions.HTTPError as e:
                         shutil.rmtree(model_path)
                         if e.response.status_code == 404:
@@ -128,7 +129,7 @@ class SentenceTransformer(nn.Sequential):
         :param show_progress_bar: Output a progress bar when encode sentences
         :param output_value:  Default sentence_embedding, to get sentence embeddings. Can be set to token_embeddings to get wordpiece token embeddings.
         :param convert_to_numpy: If true, the output is a list of numpy vectors. Else, it is a list of pytorch tensors.
-        :param convert_to_tensor: If true, you get one large tensor as return. Overwrites any setting from conver_to_numy
+        :param convert_to_tensor: If true, you get one large tensor as return. Overwrites any setting from conver_to_numpy
         :param is_pretokenized: If is_pretokenized=True, sentences must be a list of integers, containing the tokenized sentences with each token convert to the respective int.
         :param device: Which torch.device to use for the computation
         :param num_workers: Number of background-workers to tokenize data. Set to positive number to increase tokenization speed
@@ -655,4 +656,4 @@ class SentenceTransformer(nn.Sequential):
         """
         Property to set the maximal input sequence length for the model. Longer inputs will be truncated.
         """
-        self._first_module().max_seq_length = value
\ No newline at end of file
+        self._first_module().max_seq_length = value
